@@ -2,6 +2,7 @@ mod conversion;
 
 use crate::conversion::{to_mapping, to_sequence};
 use clap::{ArgEnum, Parser};
+use serde::Serialize;
 use serde_yaml::Value;
 use std::process::exit;
 
@@ -21,11 +22,17 @@ struct Args {
     #[clap(arg_enum, short, long, default_value_t = OutputType::Json, help = "Sets the output format")]
     output_type: OutputType,
 
+    #[clap(short, long, help = "accept yaml/json input from stdin")]
+    stdin: bool,
+
     values: Vec<String>,
 }
 
 impl OutputType {
-    pub fn stringify_value(&self, value: Value) -> Result<String, Box<dyn std::error::Error>> {
+    pub fn stringify_value<V: Serialize>(
+        &self,
+        value: V,
+    ) -> Result<String, Box<dyn std::error::Error>> {
         Ok(match self {
             OutputType::Toml => toml::to_string(&value)?,
             OutputType::Yaml => serde_yaml::to_string(&value)?,
@@ -48,15 +55,17 @@ fn array_implied(values: &Vec<String>) -> bool {
     true
 }
 
-fn main() {
-    let args = <Args as Parser>::parse();
+fn from_stdin() -> Option<Value> {
+    serde_yaml::from_reader(std::io::stdin())
+        .map(|value| Some(value))
+        .unwrap_or_else(|error| {
+            eprintln!("Could not parse input from stdin: {}", error);
 
-    let value = if args.array || array_implied(&args.values) {
-        to_sequence(args.values)
-    } else {
-        to_mapping(args.values)
-    };
+            None
+        })
+}
 
+fn output<V: Serialize>(value: V, args: &Args) {
     match args.output_type.stringify_value(value) {
         Ok(value) => println!("{}", value),
         Err(error) => {
@@ -67,6 +76,25 @@ fn main() {
     }
 }
 
+fn main() {
+    let args = <Args as Parser>::parse();
+
+    if args.stdin {
+        let value = from_stdin();
+
+        output(value.clone().unwrap_or_default(), &args);
+        std::process::exit(value.map_or(1, |_| 0));
+    }
+
+    let value = if args.array || array_implied(&args.values) {
+        to_sequence(args.values.clone())
+    } else {
+        to_mapping(args.values.clone())
+    };
+
+    output(value, &args);
+}
+
 #[cfg(test)]
 mod tests {
     use crate::array_implied;
